/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: 8960_SUPSTPS_INCLUI_PEDIDO_OL

Descrio:
Importao das solicitaes de compras das filiais para proveniente gerao
dos pedidos do OL

@P_DTINICIAL   - Data inicial.
@P_DTFINAL     - Data final.
@P_CDPRODINI   - Cdigo de produto inicial.
@P_CDPRODFIN   - Cdigo de produto final.
@P_CDFILLANC   - Cdigo da Filial de Lanamento
@P_CDREGIAO    - Cdigo da Regio
@P_CDGRUPFILI  - Agrupamento de Filiais
@P_CDOPERADOR  - Operador responsvel

Criao:
13/03/2007 Marcelo Alexsandro Souza Silva
*/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'INCLUI_PEDIDO_OL'  and
            type = 'P'                    and
            u.uid = o.uid                 and
            u.name = USER)
   DROP PROCEDURE INCLUI_PEDIDO_OL;
GO

CREATE PROCEDURE INCLUI_PEDIDO_OL
   @P_DTINICIAL    DATETIME,
   @P_DTFINAL      DATETIME,
   @P_PRODINI      VARCHAR(20),
   @P_PRODFIN      VARCHAR(20),
   @P_CDFILLANC    VARCHAR(4),
   @P_CDREGIAO     VARCHAR(2000),
   @P_CDGRUPFILI   VARCHAR(2000),
   @P_CDOPERADOR   VARCHAR(12),
   @P_CDGRUPPROD   VARCHAR(10),
   @P_CDSUBGRPROD  VARCHAR(2000),
   @P_ROWSAFFECT   VARCHAR(1) OUTPUT,
   @P_CDFATPRECO   VARCHAR(3)
AS
   DECLARE @V_EMITENTE          VARCHAR(4);
   DECLARE @V_PRODINI           VARCHAR(30);
   DECLARE @V_PRODFIN           VARCHAR(30);
   DECLARE @V_LISTA_FILIAL      VARCHAR(20); /* NUMERO DA PRXLISTA SOBRE FILIAL */
   DECLARE @V_NRPEDEXOL         VARCHAR(20);
   DECLARE @V_TREGIAO           VARCHAR(1);
   DECLARE @V_TPRODUTO          VARCHAR(1);
   DECLARE @V_TGRUPFILI         VARCHAR(1);
   DECLARE @V_ITEM_CONSOLIDADO  VARCHAR(1);
   DECLARE @V_IDTIPEMIT         VARCHAR(1);
   DECLARE @V_CDFILLANC         VARCHAR(4);
   DECLARE @V_CDEMPRESA         VARCHAR(2);
   DECLARE @V_MARCA             VARCHAR(5);

   DECLARE @V_PRIMEIRO_REGISTRO VARCHAR(1);
   DECLARE @W_T                 VARCHAR(1);
   DECLARE @W_A                 VARCHAR(1);
   DECLARE @W_N                 VARCHAR(1);
   DECLARE @W_S                 VARCHAR(1);
   DECLARE @W_UM                INT       ;
   DECLARE @W_ZERO              INT       ;

   DECLARE @V_QTDERESTANTE      DOUBLE PRECISION;
   DECLARE @V_QTDEPRODUTO       DOUBLE PRECISION;
   DECLARE @V_CONTADOR          DOUBLE PRECISION;
   DECLARE @V_AUXQTDERESTANTE   DOUBLE PRECISION;

   DECLARE @V_EMBALAGEM_CDPRODUTO  VARCHAR(10);
   DECLARE @V_EMBALAGEM_CDARVPROD  VARCHAR(20);
   DECLARE @V_EMBALAGEM_VRFATOCONV DOUBLE PRECISION;
   DECLARE @V_EMBALAGEM_VRARREDCMP DOUBLE PRECISION;


   DECLARE @V_ITEMSOLI_CDFILSOLI    VARCHAR(4);
   DECLARE @V_ITEMSOLI_CDPRODUTO    VARCHAR(10);
   DECLARE @V_ITEMSOLI_CDARVPROD    VARCHAR(20)
   DECLARE @V_ITEMSOLI_DTPROGENTR   DATETIME;
   DECLARE @V_ITEMSOLI_CDFILIOPELOG VARCHAR(4);
   DECLARE @V_ITEMSOLI_NRSEQUCONSOL VARCHAR(10);
   DECLARE @V_ITEMSOLI_QTSOLIPROD   DOUBLE PRECISION;
   DECLARE @V_ITEMSOLI_CDMARCA      VARCHAR(5);
   DECLARE @V_EMBALAGEM_CDMARCA     VARCHAR(5);

   DECLARE @V_PRXLOG                VARCHAR(20);

BEGIN
   /*Salvar log do filtro utilizado na rotina*/
   EXEC TEKNISA.NOVO_CODIGO 'LOGIMPSOLPEDOL', @P_SEQUENCIAL = @V_PRXLOG OUTPUT;
      SET @V_PRXLOG = SUBSTRING(@V_PRXLOG, 11, 10);
   INSERT INTO LOGIMPSOLPEDOL
          (NRSEQLOGIMPOL, DTINICIAL,   DTFINAL,   CDFILLANC,   CDOPERADOR,   CDPRODINI, CDPRODFIN, DSCDREGIAO, DSCDGRUPFILI, CDGRUPPROD,   DSCDSUBGRPROD, DTOPERACAO)
   VALUES (@V_PRXLOG,     @P_DTINICIAL, @P_DTFINAL, @P_CDFILLANC, @P_CDOPERADOR, @P_PRODINI, @P_PRODFIN, SUBSTRING(@P_CDREGIAO, 1, 250), SUBSTRING(@P_CDGRUPFILI, 1, 250), @P_CDGRUPPROD, SUBSTRING(@P_CDSUBGRPROD, 1, 250), GETDATE());

   SET @P_ROWSAFFECT = 'N';
   SET @W_T     = 'T';
   SET @W_A     = 'A';
   SET @W_N     = 'N';
   SET @W_S     = 'S';
   SET @W_UM    = 1;
   SET @W_ZERO  = 0;
   IF @P_CDREGIAO IS NULL BEGIN
     SET @V_TREGIAO = 'T';
   END;
   IF @P_CDGRUPFILI IS NULL BEGIN
     SET @V_TGRUPFILI = 'T';
   END;
   SET @V_LISTA_FILIAL = 'LISTA';
   EXEC NOVO_CODIGO @V_LISTA_FILIAL, @P_SEQUENCIAL = @V_LISTA_FILIAL OUTPUT;
   SET @V_LISTA_FILIAL = SUBSTRING(@V_LISTA_FILIAL, 11, 10);

   IF @V_TGRUPFILI = 'T' BEGIN
      INSERT INTO LISTA (NRLISTA, CDLISTA)
      SELECT
         @V_LISTA_FILIAL,
         CDFILIAL
      FROM
         FILIAL;
   END
   ELSE BEGIN
      INSERT INTO LISTA (NRLISTA, CDLISTA)
      SELECT
         @V_LISTA_FILIAL,
         FILGRUPFILI.CDFILIAL
      FROM
         FILGRUPFILI
      WHERE CHARINDEX(FILGRUPFILI.CDGRUPFILI, @P_CDGRUPFILI) > @W_ZERO
        AND NOT EXISTS (SELECT @W_UM
                        FROM LISTA L
                        WHERE L.NRLISTA = @V_LISTA_FILIAL
                          AND L.CDLISTA = FILGRUPFILI.CDFILIAL);
   END;

   IF (@P_PRODINI IS NULL) AND (@P_PRODFIN IS NULL) BEGIN
      SET @V_TPRODUTO = 'T';
   END
   ELSE BEGIN
      IF @P_PRODINI > @P_PRODFIN BEGIN
         SET @V_PRODINI = @P_PRODINI + 'ZZZZZZZZZZ';
         SET @V_PRODFIN = @P_PRODFIN;
      END
      ELSE BEGIN
         SET @V_PRODFIN = @P_PRODFIN + 'ZZZZZZZZZZ';
         SET @V_PRODINI = @P_PRODINI;
      END;
   END;

   DECLARE C_ITEMSOLI CURSOR FOR
      SELECT
         ITEMSOLI.CDFILSOLI,
         PRODESTO.CDPRODUTO,
         PRODESTO.CDARVPROD,
         ITEMSOLI.DTPROGENTR,
         ITEMSOLI.CDFILIOPELOG,
         ITEMSOLI.NRSEQUCONSOL,
         SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) QTSOLIPROD,
         ISNULL(ITEMSOLI.CDMARCA, PARASUPRI.CDMARCA) CDMARCA
      FROM ITEMSOLI, PRODUTO, PRODUTO PRODESTO, PARAMGERAL, PARASUPRI, FILIAL F
      WHERE ITEMSOLI.DTPROGENTR BETWEEN @P_DTINICIAL AND @P_DTFINAL
        AND ((PRODESTO.CDARVPROD  BETWEEN @V_PRODINI AND @V_PRODFIN) OR @V_TPRODUTO = @W_T)
        AND ITEMSOLI.CDFILIOPELOG IS NOT NULL
        AND ITEMSOLI.NRSEQUCONSOL IS NOT NULL
        AND ISNULL(ITEMSOLI.IDPEDIDOOL, @W_N) = @W_N
        AND ITEMSOLI.CDFILIOPELOG <> ITEMSOLI.CDFILSOLI
        AND ISNULL(ITEMSOLI.IDSOLIAPROV, @W_S) = @W_S
        AND ISNULL(ITEMSOLI.IDITMCONS, @W_N) = @W_N
        AND PRODUTO.CDPRODUTO      = ITEMSOLI.CDPRODUTO
        AND PRODUTO.CDPRODESTO     = PRODESTO.CDPRODUTO
        AND PARASUPRI.CDFILIAL     = ISNULL(F.CDFILCENTCMP, F.CDFILIAL)
        AND F.CDFILIAL             = ITEMSOLI.CDFILSOLI
        AND ((ISNULL(PARAMGERAL.IDRESTRFILIOPER, 'N') = 'N')
             OR
             (EXISTS (SELECT @W_UM
                      FROM FILIOPER
                      WHERE FILIOPER.CDOPERADOR = @P_CDOPERADOR
                        AND FILIOPER.CDFILIAL   = ITEMSOLI.CDFILSOLI))
            )
        AND (@P_CDSUBGRPROD IS NULL OR
             EXISTS (SELECT @W_UM
                     FROM PRSUBGRPROD
                     WHERE PRSUBGRPROD.CDGRUPPROD = @P_CDGRUPPROD
                       AND CHARINDEX(PRSUBGRPROD.CDSUBGRPROD, @P_CDSUBGRPROD) > @W_ZERO
                       AND PRSUBGRPROD.CDPRODUTO  = PRODUTO.CDPRODUTO)
             )
        AND EXISTS (SELECT @W_UM
                    FROM FILIAL, LISTA
                    WHERE LISTA.NRLISTA   = @V_LISTA_FILIAL
                      AND LISTA.CDLISTA   = FILIAL.CDFILIAL
                      AND FILIAL.CDFILIAL = ITEMSOLI.CDFILSOLI
                      AND ((CHARINDEX(FILIAL.CDREGIAO, @P_CDREGIAO) > @W_ZERO) OR @V_TREGIAO = @W_T)
                    )
        AND ITEMSOLI.NRSEQUCONSOL  = (SELECT MAX(I.NRSEQUCONSOL)
                                          FROM ITEMSOLI I
                                         WHERE I.CDFILSOLI  = ITEMSOLI.CDFILSOLI
                                           AND I.CDFILLAN   = ITEMSOLI.CDFILLAN
                                           AND I.CDPRODUTO  = ITEMSOLI.CDPRODUTO
                                           AND I.DTPROGENTR = ITEMSOLI.DTPROGENTR
                                           AND I.CDFILIOPELOG IS NOT NULL
                                           AND I.NRSEQUCONSOL IS NOT NULL
                                           AND ISNULL(I.IDPEDIDOOL, @W_N) = @W_N
                                           AND I.CDFILIOPELOG <> I.CDFILSOLI
                                           AND ISNULL(I.IDSOLIAPROV, @W_S) = @W_S
                                           AND ISNULL(I.IDITMCONS, @W_N) = @W_N)
      GROUP BY
         ITEMSOLI.CDFILSOLI,
         PRODESTO.CDPRODUTO,
         PRODESTO.CDARVPROD,
         ITEMSOLI.DTPROGENTR,
         ITEMSOLI.CDFILIOPELOG,
         ITEMSOLI.NRSEQUCONSOL,
         ISNULL(ITEMSOLI.CDMARCA, PARASUPRI.CDMARCA)
      ORDER BY
         ITEMSOLI.CDFILIOPELOG,
         ITEMSOLI.CDFILSOLI,
         PRODESTO.CDPRODUTO,
         ITEMSOLI.DTPROGENTR
   FETCH NEXT FROM C_ITEMSOLI INTO @V_ITEMSOLI_CDFILSOLI,
                                   @V_ITEMSOLI_CDPRODUTO,
                                   @V_ITEMSOLI_CDARVPROD,
                                   @V_ITEMSOLI_DTPROGENTR,
                                   @V_ITEMSOLI_CDFILIOPELOG,
                                   @V_ITEMSOLI_NRSEQUCONSOL,
                                   @V_ITEMSOLI_QTSOLIPROD;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      SET @V_QTDERESTANTE = @V_ITEMSOLI_QTSOLIPROD;
      SET @V_QTDEPRODUTO  = @W_ZERO;
      SET @V_ITEM_CONSOLIDADO = @W_N;
      SET @V_EMBALAGEM_CDPRODUTO  = '';
      SET @V_EMBALAGEM_CDARVPROD  = '';
      SET @V_EMBALAGEM_VRFATOCONV = 1;
      SET @V_EMBALAGEM_VRARREDCMP = 0;
      SET @V_EMBALAGEM_CDMARCA    = '';
      SET @V_PRIMEIRO_REGISTRO = 'S';
      OPEN C_ITEMSOLI;
      DECLARE C_EMBALAGEM CURSOR FOR
         SELECT
            CASE PRODCONSSOLOL.CDPRODUTO
               WHEN PRODUTO_OL.CDPRODARVOL 
               THEN PRODUTO_OL.CDPRODUTO 
               ELSE PRODUTO.CDPRODUTO 
            END CDPRODUTO, 
            CASE PRODCONSSOLOL.CDPRODUTO 
               WHEN PRODUTO_OL.CDPRODARVOL 
               THEN PRODUTO_OL.CDARVPROD 
               ELSE PRODUTO.CDARVPROD 
            END CDARVPROD, 
            CASE PRODCONSSOLOL.CDPRODUTO 
               WHEN PRODUTO_OL.CDPRODARVOL 
               THEN ISNULL(PRODUTO_OL.VRFATOCONV, @W_UM)
               ELSE ISNULL(PRODUTO.VRFATOCONV, @W_UM)
            END VRFATOCONV, 
            CASE PRODCONSSOLOL.CDPRODUTO 
               WHEN PRODUTO_OL.CDPRODARVOL 
               THEN ISNULL(PRODUTO_OL.VRARREDCMP, @W_ZERO)
               ELSE ISNULL(PRODUTO.VRARREDCMP, @W_ZERO)
            END VRARREDCMP, 
            PRODUTO_OL.CDMARCA
         FROM PRODUTO, PRODCONSSOLOL, (SELECT RELACPRODOL.CDPRODARVOL, RELACPRODOL.CDPRARVORIG, RELACPRODOL.CDMARCA, 
                                              PRODUTO_ORIG.CDPRODESTO, PRODUTO_ORIG.CDARVPROD, PRODUTO_ORIG.CDPRODUTO, 
                                              PRODUTO_ORIG.VRFATOCONV, PRODUTO_ORIG.VRARREDCMP, PROCESTO_OL.CDPRODESTO CDPROCESTO_OL 
                                         FROM RELACPRODOL, PRODUTO PRODUTO_ORIG, PRODUTO PROCESTO_OL 
                                        WHERE RELACPRODOL.CDPRARVORIG = PRODUTO_ORIG.CDPRODUTO
                                          AND RELACPRODOL.CDPRODARVOL = PROCESTO_OL.CDPRODUTO 
                                          AND PRODUTO_ORIG.CDPRODESTO = @V_ITEMSOLI_CDPRODUTO
                                          AND RELACPRODOL.CDMARCA       = @V_ITEMSOLI_CDMARCA) PRODUTO_OL
         WHERE PRODUTO.CDPRODESTO          = CASE PRODCONSSOLOL.CDPRODUTO 
                                                  WHEN PRODUTO_OL.CDPRODARVOL 
                                                  THEN PRODUTO_OL.CDPROCESTO_OL 
                                                  ELSE @V_ITEMSOLI_CDPRODUTO
                                               END
            AND PRODCONSSOLOL.CDPRODUTO    = PRODUTO.CDPRODUTO
            AND PRODCONSSOLOL.NRSEQUCONSOL = @V_ITEMSOLI_NRSEQUCONSOL
            AND PRODCONSSOLOL.CDFILSOLI    = @V_ITEMSOLI_CDFILIOPELOG
            AND EXISTS (SELECT @W_UM
                        FROM ITEMCONSSOLOL
                        WHERE ITEMCONSSOLOL.NRSEQUCONSOL  = @V_ITEMSOLI_NRSEQUCONSOL
                          AND ITEMCONSSOLOL.CDFILSOLI     = @V_ITEMSOLI_CDFILIOPELOG
                          AND ITEMCONSSOLOL.CDFILLAN      = PRODCONSSOLOL.CDFILLAN
                          AND ITEMCONSSOLOL.CDPRODUTO     = PRODCONSSOLOL.CDPRODUTO
                          AND ITEMCONSSOLOL.DTENTRCONSOL <= @V_ITEMSOLI_DTPROGENTR)
            AND EXISTS (SELECT @W_UM
                        FROM ITMPRODCONSSOLOL
                        WHERE ITMPRODCONSSOLOL.NRSEQUCONSOL    =  PRODCONSSOLOL.NRSEQUCONSOL
                           AND ITMPRODCONSSOLOL.CDFILDEST       =  @V_ITEMSOLI_CDFILSOLI
                           AND ITMPRODCONSSOLOL.CDPRODUTO       =  PRODCONSSOLOL.CDPRODUTO
                           AND ITMPRODCONSSOLOL.CDFILSOLI       =  PRODCONSSOLOL.CDFILSOLI
                           AND ITMPRODCONSSOLOL.CDFILLAN        =  PRODCONSSOLOL.CDFILLAN)
         ORDER BY
            ISNULL(PRODUTO.VRFATOCONV, 1)*ISNULL(PRODUTO.VRARREDCMP, 1) DESC;
      OPEN C_EMBALAGEM;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         IF @V_PRIMEIRO_REGISTRO = 'N' BEGIN
            FETCH FROM C_EMBALAGEM INTO @V_EMBALAGEM_CDPRODUTO,  @V_EMBALAGEM_CDARVPROD,
                                        @V_EMBALAGEM_VRFATOCONV, @V_EMBALAGEM_VRARREDCMP,
                                        @V_EMBALAGEM_CDMARCA;
         END;
         SET @V_PRIMEIRO_REGISTRO = 'N';
         IF @V_EMBALAGEM_CDPRODUTO IS NOT NULL BEGIN
            IF @V_EMBALAGEM_VRARREDCMP > @W_ZERO BEGIN
               SET @V_CONTADOR = @V_EMBALAGEM_VRARREDCMP;
            END
            ELSE BEGIN
               SET @V_CONTADOR = @W_UM;
            END;
            SET @V_QTDEPRODUTO     = @W_ZERO;
            SET @V_AUXQTDERESTANTE = @V_QTDERESTANTE;
            WHILE ((@V_EMBALAGEM_VRFATOCONV*@V_CONTADOR) <= @V_AUXQTDERESTANTE) BEGIN
               SET @V_QTDEPRODUTO  = @V_CONTADOR;
               SET @V_QTDERESTANTE = @V_AUXQTDERESTANTE - (@V_EMBALAGEM_VRFATOCONV*@V_CONTADOR);
               IF @V_EMBALAGEM_VRARREDCMP > @W_ZERO BEGIN
                  SET @V_CONTADOR = @V_CONTADOR + @V_EMBALAGEM_VRARREDCMP;
               END
               ELSE BEGIN
                  SET @V_CONTADOR = @V_CONTADOR + @W_UM;
               END;
            END;
            /*GRAVA QUANTIDADE MENOR*/
            IF  ((@V_EMBALAGEM_VRFATOCONV*@V_QTDEPRODUTO) < @V_AUXQTDERESTANTE) BEGIN
               SET @V_QTDEPRODUTO  = @V_CONTADOR;
            END;
            IF @V_QTDEPRODUTO > @W_ZERO BEGIN
               SET @V_NRPEDEXOL = NULL;
               SET @V_CDFILLANC = NULL;
               SELECT
                  @V_CDFILLANC = MAX(PEDIDOEXOL.CDFILLANC),
                  @V_NRPEDEXOL = MAX(PEDIDOEXOL.NRPEDEXOL)
               FROM
                  PEDIDOEXOL
               WHERE PEDIDOEXOL.CDFILDEST      = @V_ITEMSOLI_CDFILSOLI
                 AND PEDIDOEXOL.CDFILIOPELOG   = @V_ITEMSOLI_CDFILIOPELOG
                 AND PEDIDOEXOL.IDTIPOEXOL     = @W_A
                 AND PEDIDOEXOL.IDBAIXEXOL     IS NULL
                 AND PEDIDOEXOL.IDBAIXEXSAI    IS NULL
                 AND EXISTS (SELECT @W_UM
                             FROM ITEMPEDEXOL
                             WHERE ITEMPEDEXOL.CDFILDEST = PEDIDOEXOL.CDFILDEST
                               AND ITEMPEDEXOL.CDFILLANC = PEDIDOEXOL.CDFILLANC
                               AND ITEMPEDEXOL.NRPEDEXOL = PEDIDOEXOL.NRPEDEXOL
                               AND (@P_CDGRUPPROD IS NULL OR
                                    EXISTS (SELECT @W_UM
                                            FROM PRSUBGRPROD
                                            WHERE PRSUBGRPROD.CDGRUPPROD = @P_CDGRUPPROD
                                              AND CHARINDEX(PRSUBGRPROD.CDSUBGRPROD, @P_CDSUBGRPROD) > @W_ZERO
                                              AND PRSUBGRPROD.CDPRODUTO  = ITEMPEDEXOL.CDPRODUTO)
                                    )
                               AND DTPROGEMBARQ = TEKNISA.CALCULA_DATAEMBARQUE_OL(@V_ITEMSOLI_CDFILIOPELOG,
                                                                                  @V_ITEMSOLI_CDFILSOLI,
                                                                                  @V_EMBALAGEM_CDARVPROD,
                                                                                  @V_ITEMSOLI_DTPROGENTR));
               IF (@V_NRPEDEXOL IS NULL) BEGIN
                  SET @V_EMITENTE  = TEKNISA.EMITENTE(@V_ITEMSOLI_CDFILSOLI, @V_EMBALAGEM_CDPRODUTO, NULL);
                  SET @V_CDEMPRESA = SUBSTRING(@V_EMITENTE, 3, 2);
                  SET @V_IDTIPEMIT = SUBSTRING(@V_EMITENTE, 1, 1);

                  SET @V_NRPEDEXOL = 'PEDIDOEXOL' + @V_ITEMSOLI_CDFILSOLI + @P_CDFILLANC;
                  EXEC NOVO_CODIGO @V_NRPEDEXOL, @P_SEQUENCIAL = @V_NRPEDEXOL OUTPUT;
                  SET @V_NRPEDEXOL = SUBSTRING(@V_NRPEDEXOL, 11, 10);
                  SET @V_CDFILLANC = @P_CDFILLANC;

                  INSERT INTO PEDIDOEXOL (CDFILDEST, CDFILLANC, NRPEDEXOL,
                                          DTPEDEXOL, IDEMITEXOL, CDEMPRESA,
                                          CDFILIOPELOG, IDTIPOEXOL)
                  VALUES (@V_ITEMSOLI_CDFILSOLI, @P_CDFILLANC, @V_NRPEDEXOL,
                          GETDATE(), @V_IDTIPEMIT, @V_CDEMPRESA,
                          @V_ITEMSOLI_CDFILIOPELOG, @W_A);
               END;

               SET @V_MARCA = NULL;
               IF @V_EMBALAGEM_CDMARCA IS NULL BEGIN
                  SELECT
                    @V_MARCA = MAX(PARASUPRI.CDMARCA)
                  FROM PARASUPRI, FILIAL F
                  WHERE PARASUPRI.CDFILIAL = ISNULL(F.CDFILCENTCMP, F.CDFILIAL)
                   AND F.CDFILIAL = @V_ITEMSOLI_CDFILSOLI;
			      END;
               IF @V_MARCA IS NULL BEGIN
                  SELECT
                     @V_MARCA = MIN(CDMARCA)
                  FROM
                     MARCPRODCOMP
                  WHERE CDPRMARCOMPL = @V_EMBALAGEM_CDPRODUTO;
               END
               ELSE BEGIN
                  SET @V_MARCA = @V_EMBALAGEM_CDMARCA;
               END;
               UPDATE ITEMPEDEXOL
               SET
                  QTPROGENPEOL    = QTPROGENPEOL + @V_QTDEPRODUTO
               WHERE CDFILDEST    = @V_ITEMSOLI_CDFILSOLI
                 AND CDFILLANC    = @V_CDFILLANC
                 AND NRPEDEXOL    = @V_NRPEDEXOL
                 AND CDMARCA      = @V_MARCA
                 AND CDPRODUTO    = @V_EMBALAGEM_CDPRODUTO
                 AND DTPROGENPEOL = @V_ITEMSOLI_DTPROGENTR;

               IF (@@ROWCOUNT <= 0) BEGIN
                  INSERT INTO ITEMPEDEXOL
                     (CDFILDEST, CDFILLANC, NRPEDEXOL, CDMARCA,
                      CDPRODUTO, DTPROGENPEOL, QTPROGENPEOL, DTPROGEMBARQ, NRSEQLOGIMPOL)
                  VALUES
                     (
                      @V_ITEMSOLI_CDFILSOLI, @V_CDFILLANC, @V_NRPEDEXOL, @V_MARCA,
                      @V_EMBALAGEM_CDPRODUTO, @V_ITEMSOLI_DTPROGENTR, @V_QTDEPRODUTO,
                      TEKNISA.CALCULA_DATAEMBARQUE_OL(@V_ITEMSOLI_CDFILIOPELOG,
                                                      @V_ITEMSOLI_CDFILSOLI,
                                                      @V_EMBALAGEM_CDARVPROD,
                                                      @V_ITEMSOLI_DTPROGENTR), @V_PRXLOG
                      );
               END;
               SET @V_ITEM_CONSOLIDADO = @W_S;
            END;
         END;
      END;

      EXEC GERA_PED_OL_EXPEDICAO @V_ITEMSOLI_CDFILSOLI, V_CDFILLANC,  V_NRPEDEXOL, @P_CDFATPRECO;
                                  
      IF @V_ITEM_CONSOLIDADO = @W_S BEGIN
         UPDATE ITEMSOLI
         SET   IDPEDIDOOL = @W_S, NRSEQLOGIMPOL = @V_PRXLOG
         WHERE ITEMSOLI.CDFILSOLI     = @V_ITEMSOLI_CDFILSOLI
           AND ITEMSOLI.DTPROGENTR    = @V_ITEMSOLI_DTPROGENTR
           AND ISNULL(ITEMSOLI.IDPEDIDOOL, @W_N)  = @W_N
           AND ISNULL(ITEMSOLI.IDSOLIAPROV, @W_S) = @W_S
           AND ISNULL(ITEMSOLI.IDITMCONS, @W_N)   = @W_N
           AND ITEMSOLI.CDFILIOPELOG <> ITEMSOLI.CDFILSOLI
           AND ITEMSOLI.CDFILIOPELOG IS NOT NULL
           AND ITEMSOLI.NRSEQUCONSOL IS NOT NULL
           AND ITEMSOLI.CDPRODUTO    IN (SELECT PRODUTO.CDPRODUTO
                                         FROM PRODUTO
                                         WHERE CDPRODESTO = @V_ITEMSOLI_CDPRODUTO);
         SET @P_ROWSAFFECT = @W_S;
      END;
      FETCH NEXT FROM C_ITEMSOLI INTO @V_ITEMSOLI_CDFILSOLI,
                                      @V_ITEMSOLI_CDPRODUTO,
                                      @V_ITEMSOLI_CDARVPROD,
                                      @V_ITEMSOLI_DTPROGENTR,
                                      @V_ITEMSOLI_CDFILIOPELOG,
                                      @V_ITEMSOLI_NRSEQUCONSOL,
                                      @V_ITEMSOLI_QTSOLIPROD;
   END;
   CLOSE C_ITEMSOLI;
   DEALLOCATE C_ITEMSOLI;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'INCLUI_PEDIDO_OL','5.80.xxx';
GO
