/* eslint-disable */
import {
  Metadata, Http, IDictionary,
  IEventParam, Loader,
} from '@zeedhi/core';
import {
  AlertService, Button, Date as dateInput, DialogService, Form, IComponentRender,
  LoadingService, Modal, ModalService, Select, SelectMultiple, TextInput, Text,
} from '@zeedhi/common';
import { IterableComponentRender, TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class TarefaController {
  public hierarquiasController = Loader.getInstance('HierarquiasController');

  // Controlla a visibilidade do botão 'Nova Tarefa'
  public isVisibleElement: boolean = !(localStorage.getItem('idpermissstarefas') === 'V');

  private dadosOriginal: IDictionary = {};

  private headerFooterModal!: Modal;

  public async setFilterTarefas({ component }: any) {
    const hierarchyUsersList: IDictionary = await this.hierarquiasController.mountHierarchyUsersArray();
    component.datasource.setFilter({
      NRFUNCIONARIO: hierarchyUsersList,
    });
  }

  public deletarTarefas() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-tarefas');
    const NRS = (grid.selectedRows.map((element: any) => element.NRCHECKLISTAGEND));
  
    LoadingService.show();
    Http.post('/deletarTarefas', {
      NRCHECKLISTAGEND: NRS,
    }).then(() => {
      Utilities.showSuccessMessage();
      grid.datasource.get();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
    })
  }

  public dialogConfirmarExclusao() {
    DialogService.show({
      name: 'button-delete',
      type: 'warning',
      title: 'Excluir Tarefas',
      text: 'Todas as informações desta(s) Tarefa(s) serão perdidas. Deseja continuar?',
      buttons: [
        {
          name: 'no',
          component: 'ZdButton',
          label: 'Não',
          events: {
            click: () => {
              DialogService.hide();
            },
          },
        },
        {
          name: 'yes',
          component: 'ZdButton',
          label: 'Sim',
          events: {
            click: () => {
              this.deletarTarefas();
              DialogService.hide();
            },
          },
          outline: true,
        },
      ],
    });
  }

  public async editTarefa({ component }: any) {
    const [dadosASetar] = await this.dadosOriginal['iterable-Card-Task'].filter((elemento: any) => elemento.NRCHECKLISTAGEND === Number(component.name.split('_')[1]));
    window.localStorage.setItem('dadosToEditTarefa', JSON.stringify(dadosASetar));
    const dataInicio: any = new Date(dadosASetar.DTHORAAGEND.slice(3,6) + dadosASetar.DTHORAAGEND.slice(0,3) + dadosASetar.DTHORAAGEND.slice(6));
    const dataFim: any = new Date(dadosASetar.DTHRFINALAGEND.slice(3,6) + dadosASetar.DTHRFINALAGEND.slice(0,3) + dadosASetar.DTHRFINALAGEND.slice(6));
    let duracao: any = (dataFim - dataInicio)/1000;
    const hora = Math.floor((duracao/3600));
    const minuto = (duracao%3600)/60;
    duracao = `${String(hora).padStart(2,'0')}:${String(minuto).padStart(2,'0')}`
    this.headerFooterModal = await ModalService.create({
      name: 'fromTypescriptModal',
      persistent: true,
      children: [
        {
          name: 'fromTypescriptHeader',
          component: 'ZdHeader',
          color: 'transparent',
          padless: true,
          elevation: 0,
          leftSlot: [
            {
              name: 'titleText',
              component: 'ZdText',
              text: 'Dados da Tarefa',
              cssClass: 'zd-theme-font-title',
            },
          ],
          rightSlot: [
            {
              name: 'closeModalButton',
              component: 'ZdButton',
              small: true,
              icon: true,
              iconName: 'mdi-close',
              events: {
                click: '{{TarefaController.closeHeaderFooterModal}}',
              },
            },
          ],
        },
        {
          name: 'form',
          component: 'ZdForm',
          cssClass: 'alinhaultimoElemento',
          children: [
            {
              name: 'EditNomeTarefa',
              label: 'Nome da Tarefa',
              component: 'ZdTextInput',
              cssClass: 'zd-input-required',
              value: `${dadosASetar.NMCHECKLISTAGEND}`,
              grid: {
                cols: 6,
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'EditTipoLocal',
              label: 'Tipo de Local',
              component: 'ZdSelectMultiple',
              cssClass: 'zd-input-required',
              dataText: 'NMTIPOLOCALCLI',
              dataValue: 'NRTIPOLOCALCLI',
              datasouce: {
                uniqueKey: "NRTIPOLOCALCLI",
                order: [
                  'NMTIPOLOCALCLI.asc',
                ],
                loandAll: true,
              },
              grid: {
                cols: 6,
              },
              events: {
                onCreated: '{{CadastroController.setTipoLocal}}',
                change: '{{CadastroController.setValuesLocalAndChecklist}}',
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'EditselectNomeLocal',
              label: 'Local',
              component: 'ZdSelectMultiple',
              cssClass: 'zd-input-required',
              dataText: 'NMLOCALCLIENTE',
              dataValue: 'NRLOCALCLIENTE',
              disabled: true,
              datasouce: {
                order: [
                  'NMLOCALCLIENTE.asc',
                ],
                loandAll: true,
              },
              grid: {
                cols: 6,
              },
              events: {
                onCreated: '{{CadastroController.setLocal}}',
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'EditselectChecklist',
              label: 'Checklist',
              component: 'ZdSelect',
              cssClass: 'zd-input-required',
              dataText: 'NMCHECKLIST',
              dataValue: 'NRCHECKLIST',
              disabled: true,
              datasouce: {
                order: [
                  'NMCHECKLIST.asc',
                ],
                loandAll: true,
              },
              grid: {
                cols: 6,
              },
              events: {
                onCreated: '{{CadastroController.setChecklist}}',
                change: '{{CadastroController.getItensChecklist}}',
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'EditselectTipoTarefa',
              label: 'Itens do checklist',
              component: 'ZdSelectMultiple',
              cssClass: 'zd-input-required',
              dataText: 'NMATIVIDADE',
              dataValue: 'NRATIVIDADECHK',
              disabled: true,
              datasouce: {
                order: [
                  'NMATIVIDADE.asc',
                ],
                loandAll: true,
              },
              grid: {
                cols: 6,
              },
              events: {
                onCreated: '{{CadastroController.setItensChecklist}}',
                change: '{{CadastroController.getEscopos}}',
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'EditselectEscopoServico',
              label: 'Escopo de Servço',
              component: 'ZdSelectMultiple',
              cssClass: 'zd-input-required',
              dataText: 'NMESCOPOSTAREFA',
              dataValue: 'NRESCOPOSTAREFA',
              disabled: true,
              datasouce: {
                order: [
                  'NMESCOPOSTAREFA.asc',
                ],
                loandAll: true,
              },
              grid: {
                cols: 6,
              },
              events: {
                onCreated: '{{CadastroController.setEscopos}}',
                change:"{{CadastroController.getTarefas}}",
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'EditselectTarefa',
              label: 'Tarefa',
              component: 'ZdSelectMultiple',
              cssClass: 'zd-input-required',
              dataText: 'NMTAREFA',
              dataValue: 'NRTAREFACHK',
              disabled: true,
              datasouce: {
                order: [
                  'NMTAREFA.asc',
                ],
                loandAll: true,
              },
              grid: {
                cols: 6,
              },
              events: {
                onCreated: '{{CadastroController.setTarefas}}',
                change: "{{CadastroController.setCriterio}}"
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'Data',
              label: 'Data',
              component: 'ZdDate',
              cssClass: 'zd-input-required',
              autocomplete: false,
              displayFormat: 'DD/MM/YYYY',
              dateFormat: 'MM/DD/YYYY',
              pickerType: 'date',
              value: `${dadosASetar.DTHORAAGEND.split(' ')[0]}`,
              grid: {
                cols: 6,
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'HoraInicio',
              component: 'ZdTime',
              autocomplete: false,
              cssClass: 'zd-input-required',
              label: 'Inicio',
              timeFormat: '24hr',
              placeholder: '00:00',
              mask: '##:##',
              value: `${dadosASetar.DTHORAAGEND.split(' ')[1]}`,
              validations: {
                required: {},
              },
              grid: {
                cols: 6,
              },
            },
            {
              name: 'TempoMedio',
              component: 'ZdTextInput',
              label: 'Duração (minutos)',
              cssClass: 'zd-input-required',
              placeholder: '00:00',
              mask: '##:M#',
              value: `${duracao}`,
              validations: {
                required: {
                  message: 'Campo Obrigatorio',
                },
                minLength: {
                  limit: 5,
                  message: 'Campo Obrigatorio',
                },
                maxLength: {
                  limit: 5,
                  message: 'Campo Obrigatorio',
                },
              },
              grid: {
                cols: 6
              }
            },
            {
              name: 'EditCriterios',
              label: 'Critérios',
              component: 'ZdSelectMultiple',
              cssClass: 'zd-input-required',
              dataText: 'DSCRITERIOTAREFA',
              dataValue: 'NRCRITERIOTAREFA',
              disabled: true,
              returnObject: true,
              datasouce: {
                order: [
                  'DSCRITERIOTAREFA.asc',
                ],
                loandAll: true,
              },
              grid: {
                cols: 9,
              },
              events: {
                onCreated: '{{CadastroController.getCriteriosDeAvaliacao}}',
              },
              validations: {
                required: {},
              },
            },
            {
              name: 'BotaoNovoCriterio',
              label: 'Novo Critérios',
              width: '100%',
              component: 'ZdButton',
              grid: {
                cols: 3,
              },
              events: {
                click: '{{TarefaController.NovoCriterio}}',
              },
            },
            {
              name: 'SalvarNovoCriterios',
              label: 'Novo Critérios',
              component: 'ZdTextInput',
              isVisible: false,
              grid: {
                cols: 9,
              },
            },
            {
              name: 'BotaoSalvarNovoCriterio',
              label: 'Salvar',
              width: '100%',
              isVisible: false,
              component: 'ZdButton',
              grid: {
                cols: 3,
              },
              events: {
                click: "{{TarefaController.salvarNovoCriterio}}"
              }
            },
            {
              name: 'EditFuncionario',
              component: 'ZdSelect',
              autocomplete: false,
              label: 'Funcionário',
              dataText: 'NMFUNCIONARIO',
              dataValue: 'NRFUNCIONARIO',
              events:{
                onBeforeMount: '{{CadastroController.setFuncionario}}'
              },
              datasource:{
                loadAll:true,
                data:[]
              },
              grid:{
                cols:6
              }
            },
            {
              name: 'EditFuncionarioVistoria',
              component: 'ZdSelect',
              autocomplete: false,
              label: 'Encarregado',
              dataText: 'NMFUNCIONARIO',
              dataValue: 'NRFUNCIONARIO',
              events:{
                onBeforeMount: '{{CadastroController.setSupervisor}}'
              },
              datasource:{
                loadAll:true,
                data:[]
              },
              grid:{
                cols:6
              }
              },
          ],
        },
        {
          name: 'LinhaComBtnSalvarECancelar',
          component: 'ZdRow',
          justify: 'end',
          children: [
            {
              name: 'CancelModalButton',
              component: 'ZdButton',
              label: 'Cancelar',
              cssClass: 'zd-mx-4',
              width: '7em',
              outline: true,
              events: {
                click: '{{TarefaController.closeHeaderFooterModal}}',
              },
            },
            {
              name: 'SaveModalButton',
              component: 'ZdButton',
              label: 'Atualizar',
              width: '7em',
              events: {
                click: '{{TarefaController.atualizarTarefa}}',
              },
            },
          ]
        }
      ],
    });
    this.headerFooterModal.show();
  }

  public closeHeaderFooterModal() {
    this.headerFooterModal.hide();
    this.headerFooterModal!.destroy();
  }

  public NovoCriterio() {
    const form = Metadata.getInstance<Form>('form');
    form.children[12].isVisible = true;
    form.children[13].isVisible = true;
  }

  public visibilidadeBtns({ component }: any) {
    const visibilidadeAcesso = !(localStorage.getItem('idpermissschecklist') === 'V');

    const visibilidadependente = (component.name.split('_')[2] === 'Pendente');
    const visibilidade = visibilidadeAcesso && visibilidadependente;
    component.isVisible = visibilidade;
  }

  public salvarNovoCriterio() {
    const criterio = Metadata.getInstance<TextInput>('SalvarNovoCriterios');
    const listaCriterio = Metadata.getInstance<SelectMultiple>('EditCriterios');
    const values = listaCriterio.value;
    const dados = listaCriterio.datasource.data;
    dados.push({
      DSCRITERIOTAREFA: criterio.value,
      NRCRITERIOTAREFA: criterio.value,
    });
    values.push({
      DSCRITERIOTAREFA: criterio.value,
      NRCRITERIOTAREFA: criterio.value,
    });
    listaCriterio.updateData(dados);
    listaCriterio.setValue(values);
    criterio.value = '';
    const form = Metadata.getInstance<Form>('form');
    form.children[12].isVisible = false;
    form.children[13].isVisible = false;
  }

/*  public async atualizarTarefa(){
    const form = Metadata.getInstance<Form>('form');
    const dados = JSON.parse(<string>localStorage.getItem('dadosToEditTarefa')) || {};
    const CDOPERADOR = localStorage.getItem('CDOPERADOR') || null;
    if (form.validate()) {
      LoadingService.show('Atualizando...');
      const dadosUpdate = form.value;
      dadosUpdate.NRCHECKLISTAGEND = dados.NRCHECKLISTAGEND;
      dadosUpdate.NRGERENCIAMENTOCHK = dados.NRGERENCIAMENTOCHK;
      dadosUpdate.CDOPERADOR = CDOPERADOR;
      await Http.post('/updateTarefa', dadosUpdate).then((response: any) => {
        if (response.data.dataset.retorno === ['OK']) {
          AlertService.show({
            name: 'basic-alert',
            text: 'Tarefa atualizada com sucesso!',
            top: true,
            left: false,
            timeout: 3000,
            color: 'success',
          });
        } else {
          DialogService.show({
            name: 'basic-dialog',
            type: 'warning',
            title: 'Transação bloqueada!',
            text: 'Ocorreu um erro durante a operação.\nTente novamente mais tarde.\nSe o erro persistir, entre em contato com o administrador do sistema.',
            buttons: [
              {
                name: 'cancel',
                component: 'ZdButton',
                outline: true,
                label: 'Voltar',
                events: {
                  click: () => DialogService.hide(),
                },
              },
            ],
          });
        }
      });
      await this.getTarefas();
      LoadingService.hide();
    }
  } */
}